@@ -18,13 +18,12 @@ from localstack.constants import (
     PATH_USER_REQUEST,
     TEST_AWS_ACCOUNT_ID,
 )
-from localstack.services.apigateway.context import ApiInvocationContext, InvocationPayload
+from localstack.services.apigateway.context import ApiInvocationContext
 from localstack.services.generic_proxy import RegionBackend
 from localstack.utils import common
 from localstack.utils.aws import aws_stack
 from localstack.utils.aws.aws_responses import requests_error_response_json, requests_response
 from localstack.utils.aws.aws_stack import parse_arn
-from localstack.utils.common import try_json
 
 LOG = logging.getLogger(__name__)
 
@@ -698,6 +697,31 @@ def handle_validators(method, path, data, headers):
     return make_error_response("Not implemented for API Gateway validators: %s" % method, code=404)
 
 
+def is_test_invoke_method(method, path):
+    return method == "POST" and bool(re.match(PATH_REGEX_TEST_INVOKE_API, path))
+
+
+def get_stage_variables(context: ApiInvocationContext) -> Optional[Dict[str, str]]:
+    if is_test_invoke_method(context.method, context.path):
+        return None
+
+    if not context.stage:
+        return {}
+
+    region_name = [
+        name
+        for name, region in apigateway_models.apigateway_backends.items()
+        if context.api_id in region.apis
+    ][0]
+    api_gateway_client = aws_stack.connect_to_service("apigateway", region_name=region_name)
+    try:
+        response = api_gateway_client.get_stage(restApiId=context.api_id, stageName=context.stage)
+        return response.get("variables")
+    except Exception:
+        LOG.info("Failed to get stage %s for API id %s", context.stage, context.api_id)
+        return {}
+
+
 # -----------------------
 # GATEWAY RESPONSES APIs
 # -----------------------
@@ -1186,109 +1210,3 @@ def import_api_from_openapi_spec(
         rest_api.endpoint_configuration = endpoint_config
 
     return rest_api
-
-
-def apply_template(
-    integration: Dict[str, Any],
-    req_res_type: str,
-    data: InvocationPayload,
-    path_params=None,
-    query_params=None,
-    headers=None,
-    context=None,
-):
-    if path_params is None:
-        path_params = {}
-    if query_params is None:
-        query_params = {}
-    if headers is None:
-        headers = {}
-    if context is None:
-        context = {}
-    integration_type = integration.get("type") or integration.get("integrationType")
-    if integration_type in ["HTTP", "AWS"]:
-        # apply custom request template
-        content_type = APPLICATION_JSON  # TODO: make configurable!
-        template = integration.get("%sTemplates" % req_res_type, {}).get(content_type)
-        if template:
-            variables = {"context": context or {}}
-            input_ctx = {"body": data}
-            # little trick to flatten the input context so velocity templates
-            # work from the root.
-            # orig - { "body": '{"action": "$default","message":"foobar"}'
-            # after - {
-            #   "body": '{"action": "$default","message":"foobar"}',
-            #   "action": "$default",
-            #   "message": "foobar"
-            # }
-            if data:
-                dict_pack = try_json(data)
-                if isinstance(dict_pack, dict):
-                    for k, v in dict_pack.items():
-                        input_ctx.update({k: v})
-
-            def _params(name=None):
-                # See https://docs.aws.amazon.com/apigateway/latest/developerguide/
-                #    api-gateway-mapping-template-reference.html#input-variable-reference
-                # Returns "request parameter from the path, query string, or header value (
-                # searched in that order)"
-                combined = {}
-                combined.update(path_params or {})
-                combined.update(query_params or {})
-                combined.update(headers or {})
-                return combined if not name else combined.get(name)
-
-            input_ctx["params"] = _params
-            data = aws_stack.render_velocity_template(template, input_ctx, variables=variables)
-    return data
-
-
-def apply_integration_response_template(context: ApiInvocationContext):
-    response = context.response
-    integration = context.integration
-    _, query_string_params = extract_query_string_params(path=context.invocation_path)
-    int_responses = integration.get("integrationResponses") or {}
-    if not int_responses:
-        return response
-    entries = list(int_responses.keys())
-    return_code = str(response.status_code)
-    if return_code not in entries:
-        if len(entries) > 1:
-            LOG.info("Found multiple integration response status codes: %s", entries)
-            return response
-    return_code = entries[0]
-
-    response_templates = int_responses[return_code].get("responseTemplates", {})
-    template = response_templates.get(APPLICATION_JSON, {})
-    if not template:
-        return response
-
-    variables = {"context": {}}
-    input_ctx = {"body": response.content}
-    # little trick to flatten the input context so velocity templates
-    # work from the root.
-    # orig - { "body": '{"action": "$default","message":"foobar"}'
-    # after - {
-    #   "body": '{"action": "$default","message":"foobar"}',
-    #   "action": "$default",
-    #   "message": "foobar"
-    # }
-    if response.content:
-        dict_pack = try_json(response.content)
-        if isinstance(dict_pack, dict):
-            for k, v in dict_pack.items():
-                input_ctx.update({k: v})
-
-    def _params(name=None):
-        # See https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-mapping-template-reference.html#input-variable-reference
-        # Returns "request parameter from the path, query string, or header value (
-        # searched in that order)"
-        combined = {}
-        combined.update({"path": context.path_params} or {})
-        combined.update(query_string_params or {})
-        combined.update(context.headers or {})
-        return combined if not name else combined.get(name)
-
-    input_ctx["params"] = _params
-    response._content = aws_stack.render_velocity_template(template, input_ctx, variables=variables)
-    return response
