@@ -4,6 +4,7 @@ import os
 import re
 import time
 from collections import defaultdict
+from functools import lru_cache
 from io import BytesIO
 from typing import Any, Dict, List, Union
 
@@ -28,9 +29,6 @@ LAMBDA_RUNTIME_PYTHON37 = "python3.7"
 LAMBDA_RUNTIME_PYTHON38 = "python3.8"
 LAMBDA_RUNTIME_PYTHON39 = "python3.9"
 LAMBDA_RUNTIME_NODEJS = "nodejs"
-LAMBDA_RUNTIME_NODEJS43 = "nodejs4.3"
-LAMBDA_RUNTIME_NODEJS610 = "nodejs6.10"
-LAMBDA_RUNTIME_NODEJS810 = "nodejs8.10"
 LAMBDA_RUNTIME_NODEJS10X = "nodejs10.x"
 LAMBDA_RUNTIME_NODEJS12X = "nodejs12.x"
 LAMBDA_RUNTIME_NODEJS14X = "nodejs14.x"
@@ -45,6 +43,7 @@ LAMBDA_RUNTIME_RUBY = "ruby"
 LAMBDA_RUNTIME_RUBY25 = "ruby2.5"
 LAMBDA_RUNTIME_RUBY27 = "ruby2.7"
 LAMBDA_RUNTIME_PROVIDED = "provided"
+LAMBDA_RUNTIME_PROVIDED_AL2 = "provided.al2"
 
 # default handler and runtime
 LAMBDA_DEFAULT_HANDLER = "handler.handler"
@@ -75,6 +74,30 @@ class ClientError(Exception):
         return error_response(self.msg, self.code)
 
 
+@lru_cache()
+def get_default_executor_mode() -> str:
+    """
+    Returns the default docker executor mode, which is "docker" if the docker socket is available via the docker
+    client, or "local"  otherwise.
+
+    :return:
+    """
+    try:
+        return "docker" if DOCKER_CLIENT.has_docker() else "local"
+    except Exception:
+        return "local"
+
+
+def get_executor_mode() -> str:
+    """
+    Returns the currently active lambda executor mode. If config.LAMBDA_EXECUTOR is set, then it returns that,
+    otherwise it falls back to get_default_executor_mode().
+
+    :return: the lambda executor mode (e.g., 'local', 'docker', or 'docker-reuse')
+    """
+    return config.LAMBDA_EXECUTOR or get_default_executor_mode()
+
+
 def multi_value_dict_for_list(elements: Union[List, Dict]) -> Dict:
     temp_mv_dict = defaultdict(list)
     for key in elements:
